@@ -40,13 +40,17 @@ rm_default <- function(text.var, trim = !extract, clean = TRUE, pattern,
 	
     if (extract) {
     	if (!trim) {
-            return(stringi::stri_extract_all_regex(text.var, pattern))
+            return(ext(stringi::stri_extract_all_regex(text.var, pattern)))
     	}
-    	return(lapply(stringi::stri_extract_all_regex(text.var, pattern), Trim))
+    	return(ext(lapply(stringi::stri_extract_all_regex(text.var, pattern), Trim)))
     }
 
     out <- gsub(pattern, replacement, text.var, perl = TRUE, ...)
     if (trim) out <- Trim(out)
     if (clean) out <- clean(out)
     out
-}
\ No newline at end of file
+}
+
+
+
+
